@@ -17,6 +17,7 @@ import sensiml.base.utility as utility
 from sensiml.datamanager import (
     Functions,
     PlatformDescriptions,
+    ClientPlatformDescriptions,
     PipelineSeeds,
     Projects,
     SegmenterSet,
@@ -92,6 +93,7 @@ class SensiML(object):
         self.datasets = DataSets()
         self.functions = Functions(self._connection)
         self.platforms = PlatformDescriptions(self._connection)
+        self.platforms_v2 = ClientPlatformDescriptions(self._connection)
         self.seeds = PipelineSeeds(self._connection)
         self.snippets = Snippets(
             self.list_functions(kp_functions=False, qgrid=False),
@@ -241,6 +243,22 @@ class SensiML(object):
             }
         )
 
+    def get_automl_parameter_inventory(self):
+        """
+        inventory paramenters for AutoML
+
+        Returns:
+            DataFrame: Automl parameter inventory
+        """
+
+        url = "automl/inventory/"
+
+        response = self._connection.request("get", url)
+
+        response_data, err = utility.check_server_response(response)
+
+        return DataFrame(response_data)
+
     def get_knowledgepack(self, uuid):
         """retrieve knowledgepack by uuid from the server associated with current project
 
@@ -453,7 +471,14 @@ class SensiML(object):
         if capture_configurations:
             query.capture_configurations = capture_configurations
 
-        query.segmenter = segmenter
+        if isinstance(segmenter, str):
+            segmenters = self.list_segmenters()
+            segmenter_id = segmenters[segmenters["name"] == segmenter].id
+            if segmenter_id.shape[0] != 1:
+                raise Exception("Segmenter {} not found".format(segmenter))
+            query.segmenter = int(segmenter_id[0])
+        else:
+            query.segmenter = segmenter
 
         if new:
             query.insert(renderer=renderer)
@@ -489,13 +514,9 @@ class SensiML(object):
         feature_file.is_features = is_features
         feature_file.path = path
         if new:
-            feature_file.insert()
+            return feature_file.insert()
         else:
-            feature_file.update()
-
-        print('Upload of file "{}"  to SensiMLKB  Cloud completed.'.format(name))
-
-        return self
+            return feature_file.update()
 
     def upload_dataframe(self, name, dataframe, force=False, is_features=False):
         """Set data source from a pandas DataFrame."""
@@ -504,11 +525,13 @@ class SensiML(object):
         with NamedTemporaryFile(delete=False) as temp:
             dataframe.to_csv(temp.name, index=False)
             logger.debug("set_dataframe:" + name + ":" + temp.name)
-            self.upload_data_file(name, temp.name, force=force, is_features=is_features)
+            result = self.upload_data_file(
+                name, temp.name, force=force, is_features=is_features
+            )
 
         os.remove(temp.name)
 
-        return self
+        return result
 
     def clear_session_cache(self):
         for _, _, filenames in os.walk(config_dir):
