@@ -134,6 +134,21 @@ class Connection(object):
             if os.path.exists(self._token_filename):
                 with open(self._token_filename, "r") as f:
                     self.session.token = JSON.load(f)
+
+                try:
+                    self.session.refresh_token(
+                        self.token_url,
+                        auth=(self.client_id, self.client_secret),
+                        verify=self._verify,
+                    )
+                    self._save_token(self.session.token)
+                except:
+                    os.remove(self._token_filename)
+                    print("Invalid ClientID, Enter Username And Password to Login")
+                    self.session.token = {}
+                    self.username = input("Enter username: ")
+                    password = getpass("Enter password: ")
+
             else:
                 self.username = input("Enter username: ")
                 password = getpass("Enter password: ")
@@ -161,6 +176,7 @@ class Connection(object):
                 self.username = None
                 return self._login(password, attempt=attempt + 1)
             self._save_token(self.session.token)
+
         logger.debug("Login completed")
 
     def request(self, method, path, json=None, params=None, headers=None, **kwargs):
