@@ -17,6 +17,8 @@ from sensiml.method_calls import (
     OptimizerCall,
     TrainingAlgorithmCall,
     CaptureFileCall,
+    AugmentationCall,
+    AugmentationCallSet,
 )
 
 
@@ -264,6 +266,7 @@ class Functions:
             )
 
         if isinstance(function, string_types):
+
             function = self.function_list.get(function, None)
 
             if function is None:
@@ -276,12 +279,14 @@ class Functions:
             return getattr(
                 self, "create_{}_call".format(function.type.lower().replace(" ", "_"))
             )(function)
+
         except Exception as e:
             print(
                 'No function call for function type "{}" found.'.format(
                     function.type.lower()
                 )
             )
+
             raise (e)
 
     def _create_base_call(self, function, CallFunction, ignore_columns=[]):
@@ -363,6 +368,28 @@ class Functions:
             function, GeneratorCall, ignore_columns=ignore_columns
         )
 
+    def create_augmentation_call(self, function):
+        """
+            Creates a AugmentationCall for the specified time series augmentation.
+
+            Args:
+                function (Function): function with which to create a augmentation call
+
+            Returns:
+                instance of AugmentationCall customized for the input function
+
+        """
+        ignore_columns = [
+            "ignore_columns",
+            "input_data",
+            "label_column",
+            "num_features",
+        ]
+
+        return self._create_base_call(
+            function, AugmentationCall, ignore_columns=ignore_columns
+        )
+
     def create_feature_selector_call(self, function):
         """Creates a SelectorCall for the specified selector.
 
@@ -470,6 +497,11 @@ class Functions:
         scs = SelectorCallSet(name)
         return scs
 
+    def create_augmentation_call_set(self, name="AugmentationCallSet"):
+        """Creates an empty augmentation call set."""
+        acs = AugmentationCallSet(name)
+        return acs
+
     def create_training_algorithm_call(self, function, name=None):
         """Creates a training algorithm method call for the specified function.
 
