@@ -19,6 +19,7 @@ from sensiml.datamanager.confusion_matrix import (
 )
 from sensiml.datamanager.deviceconfig import DeviceConfig
 from sensiml.datamanager.platformdescription import PlatformDescription
+from sensiml.datamanager.clientplatformdescription import ClientPlatformDescription
 from sensiml.visualize.knowledgepack_visualize_mixin import VisualizeMixin
 
 
@@ -458,6 +459,8 @@ class KnowledgePack(VisualizeMixin):
                 self._name = name
                 print("Knowledgepack " + uuid + " deleted.")
 
+                return response
+
     def save(self, name):
         """Save a knowledpack with a name.
 
@@ -491,6 +494,20 @@ class KnowledgePack(VisualizeMixin):
                 self._name = name
                 print("Knowledgepack '" + name_list[list_index] + "' updated.")
 
+                return response
+
+    def terminate_download(self):
+        url = "project/{0}/sandbox/{1}/knowledgepack/{2}/generate_lib/".format(
+            self._project_uuid, self._sandbox_uuid, self.uuid
+        )
+
+        response = self._connection.request("delete", url)
+        response, err = utility.check_server_response(response)
+        if err is False:
+            print(response)
+
+            return response
+
     def download_library(
         self, folder="", run_async=True, platform=None, renderer=None, *args, **kwargs
     ):
@@ -554,6 +571,69 @@ class KnowledgePack(VisualizeMixin):
             **kwargs
         )
 
+    def download_library_v2(
+        self, folder="", run_async=True, platform=None, renderer=None, *args, **kwargs
+    ):
+        """Calls the server to generate static library image based on device config.
+
+        Args:
+            folder (str): Folder to save to if not generating a link
+
+        Returns:
+            str: Denoting success, or link to file download
+        """
+        return self._download_v2(
+            folder=folder,
+            bin_or_lib="lib",
+            run_async=run_async,
+            platform=platform,
+            renderer=renderer,
+            *args,
+            **kwargs
+        )
+
+    def download_source_v2(
+        self, folder="", run_async=True, platform=None, renderer=None, *args, **kwargs
+    ):
+        """Calls the server to generate static library image based on device config.
+
+        Args:
+            folder (str): Folder to save to if not generating a link
+
+        Returns:
+            str: Denoting success, or link to file download
+        """
+        return self._download_v2(
+            folder=folder,
+            bin_or_lib="source",
+            run_async=run_async,
+            platform=platform,
+            renderer=renderer,
+            *args,
+            **kwargs
+        )
+
+    def download_binary_v2(
+        self, folder="", run_async=True, platform=None, renderer=None, *args, **kwargs
+    ):
+        """Calls the server to generate full binary image based on device config.
+
+        Args:
+            folder (str): Folder to save to if not generating a link
+
+        Returns:
+            str: Denoting success, or link to file download
+        """
+        return self._download_v2(
+            folder=folder,
+            bin_or_lib="bin",
+            run_async=run_async,
+            platform=platform,
+            renderer=renderer,
+            *args,
+            **kwargs
+        )
+
     def get_sandbox_device_config(self):
         url = "project/{0}/sandbox/{1}/device_config/".format(
             self._project_uuid, self._sandbox_uuid
@@ -563,6 +643,114 @@ class KnowledgePack(VisualizeMixin):
         if err is False:
             return response_data.json().get("device_config")
 
+    def _download_v2(
+        self,
+        folder,
+        bin_or_lib,
+        run_async=False,
+        platform=None,
+        renderer=None,
+        *args,
+        **kwargs
+    ):
+        _path = r"{0}".format(folder)
+        url = "project/{0}/sandbox/{1}/knowledgepack/{2}/generate_{3}/v2".format(
+            self._project_uuid, self._sandbox_uuid, self.uuid, bin_or_lib
+        )
+        # config = self._sandbox.device_config.copy() # get a regular dictionary
+
+        if platform is not None and type(platform) is ClientPlatformDescription:
+            kwargs["config"] = {"target_platform": platform.id}
+        elif platform is not None and type(platform) is not ClientPlatformDescription:
+            err_msg = "Platform not properly specified. Specify via dsk.platforms()"
+            if renderer:
+                renderer.render(err_msg)
+            return err_msg, False
+
+        config = kwargs.pop("config", None)
+        if config:
+            if "kb_description" in config and isinstance(
+                config["kb_description"], dict
+            ):
+                config["kb_description"] = json.dumps(config["kb_description"])
+            for key in kwargs:
+                if key in [
+                    "debug",
+                    "test_data",
+                    "sample_rate",
+                    "output_options",
+                    "debug_level",
+                    "profile",
+                    "profile_iterations",
+                    "target_processor",
+                    "target_compiler",
+                    "float_options",
+                    "extra_build_flags",
+                ]:
+                    config.update({key: kwargs[key]})
+                if key == "kb_description":
+                    config.update({key: json.dumps(kwargs[key])})
+        else:
+            config = self.get_sandbox_device_config()
+
+        print("Generating {} with configuration".format(bin_or_lib))
+        for key in config:
+            print("{} : {}".format(key, config[key]))
+
+        if config.get("target_platform", None) is None:
+            raise KnowledgePackException("Target platform must be specified.")
+        config["asynchronous"] = run_async
+        response = self._connection.request("post", url, data=config)
+        response_data, err = utility.check_server_response(
+            response, is_octet=True, renderer=renderer
+        )
+
+        msg = "Generating Knowledge Pack"
+        count = 0
+        while True:
+            response = self._connection.request("get", url)
+            response_data, err = utility.check_server_response(
+                response, is_octet=True, renderer=renderer
+            )
+            if (
+                err
+                or "content-disposition" in response_data.headers
+                or response_data.json().get("task_state") in ("FAILURE",)
+            ):
+                break
+            sys.stdout.write(".")
+            if renderer:
+                msg += " ."
+                renderer.render(msg)
+            sleep(5)
+        if "content-disposition" in response_data.headers:
+            if kwargs.get("save_as"):
+                filename = kwargs.get("save_as", None)
+            else:
+                filename = re.findall(
+                    'filename="([^"]+)"', response_data.headers["content-disposition"]
+                )[0]
+            if filename is None:
+                filename = re.findall(
+                    'filename="([^"]+)"', response_data.headers["content-disposition"]
+                )[0]
+            file_path = os.path.join(_path, filename)
+            with open(file_path, "wb") as f:
+                for d in response_data.iter_content(2048):
+                    f.write(d)
+
+            output_path = os.path.join(os.path.abspath("."), file_path)
+            if renderer:
+                renderer.render("KnowledgePack saved to\n{0}".format(output_path))
+
+            return output_path, True
+        else:
+            err_msg = response_data.json().get("task_result")
+            print(err_msg)
+            if renderer:
+                renderer.render(err_msg)
+            return err_msg, False
+
     def _download(
         self,
         folder,
