@@ -150,10 +150,10 @@ class ModelMetrics(object):
             metric_set = getattr(self, "_" + metric)
             if metric_set["train"] is not None:
                 msg += "{:>25}:    ".format(metric.upper())
-                for key in ['train', 'test', 'validation']:
+                for key in ["train", "test", "validation"]:
                     if metric_set[key] is not None:
                         msg += "{}: {:.2f}  ".format(key, metric_set[key])
-                msg += '\n'
+                msg += "\n"
 
         print(msg)
 
@@ -267,53 +267,6 @@ class ModelMetrics(object):
         output += str(self.confusion_matrix_stats[metrics_set])
         return output
 
-    def get_positive_predictive_indexes(self, class_name, metric_set="validation"):
-        """
-        Returns the indicides of positive predictive classes in the validation set.
-
-
-        Args:
-            class_name (string): name of class to get indices for
-
-        """
-        return [
-            self.validation_set[x]
-            for x in self.knowledgepack.get_positive_predictive_indexes(
-                class_name, metric_set=metric_set
-            )
-        ]
-
-    def get_false_positive_indexes(self, class_name, metric_set="validation"):
-        """
-        Returns the indicides of false positives in the validation set.
-
-        Args:
-            class_name (string): name of class to get indices for
-
-
-        """
-        return [
-            self.validation_set[x]
-            for x in self.knowledgepack.get_false_positive_indexes(
-                class_name, metric_set=metric_set
-            )
-        ]
-
-    def get_true_positive_indexes(self, class_name, metric_set="validation"):
-        """
-         Returns the indicides of true positive classification in the validation set.
-
-        Args:
-            class_name (string): name of class to get indices for
-        """
-
-        return [
-            self.validation_set[x]
-            for x in self.knowledgepack.get_true_positive_indexes(
-                class_name, metric_set=metric_set
-            )
-        ]
-
 
 class Configuration(object):
     def __init__(self, result_set, sandbox, config_result):
@@ -487,4 +440,3 @@ class ModelResultSet(object):
             self._input_data = DataFrame.from_dict(json.loads(init_dict["input_data"]))
         for _, config in self._results_dict["configurations"].items():
             self.configurations.append(Configuration(self, self._sandbox, config))
-
