@@ -1,5 +1,3 @@
-
-
 class DataSegment(object):
     def __init__(self, data, metadata, label=None):
         self._metadata = metadata
@@ -15,15 +13,14 @@ class DataSegment(object):
 
 
 class DataSegments(dict):
-
     def plot(self, **kwargs):
         import matplotlib as plt
-        plt.rcParams.update({'figure.max_open_warning': 0})
+
+        plt.rcParams.update({"figure.max_open_warning": 0})
         for _, segment in self.items():
             segment.plot(**kwargs)
 
 
-
 def to_datasegments(data, metdata_columns, label_column):
     """ Converts a dataframe into a data segments object"""
 
@@ -41,7 +38,6 @@ def to_datasegments(data, metdata_columns, label_column):
 
         tmp_df = g.get_group(key)[data_columns]
 
-        ds[tmp_df['uuid']] = DataSegment(tmp_df, metadata, metadata[label_column])
+        ds[tmp_df["uuid"]] = DataSegment(tmp_df, metadata, metadata[label_column])
 
     return ds
-
