@@ -146,8 +146,8 @@ class DCLProject:
 
         if query_filter:
             query_where = (
-                query_filter
-            )  # + "AND {}.local_status != 2 ".format(tablename)
+                query_filter  # + "AND {}.local_status != 2 ".format(tablename)
+            )
         else:
             query_where = ""  # "WHERE {}.local_status != 2 ".format(tablename)
 
