@@ -7,6 +7,8 @@ from requests.exceptions import HTTPError
 from six import string_types
 import numpy as np
 
+from pandas import DataFrame
+
 from sensiml.base.exceptions import DuplicateValueError
 import sensiml.base.utility as utility
 from sensiml.base.snippets import generate_pipeline
@@ -109,6 +111,28 @@ class Pipeline(object):
         else:
             print("Error: group_columns must be a list.")
 
+    def get_automl_iteration_metrics(self):
+        """ 
+            Results of automl stats for each iteration
+            
+            Returns:
+                DataFrame: Automl resutls stats
+        """
+
+        url = "project/{0}/sandbox/{1}/automl-iteration-metrics/".format(
+            self._project.uuid, self._sandbox.uuid
+        )
+
+        response = self._project._connection.request("get", url)
+
+        response_data, err = utility.check_server_response(response)
+
+        response_data = DataFrame(response_data)
+
+        return response_data.sort_values(
+            by=["original_iteration", "fitness"], ascending=[True, False]
+        )
+
     def get_knowledgepack(self, uuid):
         """retrieve knowledgepack by uuid from the server
 
@@ -917,6 +941,25 @@ class Pipeline(object):
 
         self._add_feature_selector(feature_selectors, params)
 
+    def add_augmentation(self, augmentation, params={}):
+        """
+            Add augmentation set to the pipeline.
+
+            Args:
+                augmentation (List): List of dictionaries containing time series augmentations
+                params (dict, {}): Parameters of the feature selector set.
+
+            Examples:
+                >>> dsk.pipeline.add_augmentation([{"name": "Add Noise", "params": {"scale": [0.05, 0.1, 0.15 ],  # , 0.1, 0.15
+                >>>                                                                 "target_labels": ['idle','walking'],
+                >>>                                                                 "target_sensors": ['AccelerometerX', 'GyroscopeX']   
+                >>>                                                                }}
+                >>>                                   ])
+      
+        """
+
+        self._add_augmentation(augmentation, params)
+
     def set_validation_method(self, name, params={}):
         """Set the validation method for the tvo step.
 
@@ -1127,12 +1170,43 @@ class Pipeline(object):
 
         self._sandbox.add_linear_step(generator_set)
 
-    def _add_feature_selector(self, feature_selectors, selector_set_params={}):
+    def _add_augmentation(self, augmentations, augmentation_set_params={}):
 
         self._check_for_input_data()
 
-        selector_set = self._kb.functions.create_selector_call_set("selector_set")
+        augmentation_set = self._kb.functions.create_augmentation_call_set(
+            "augmentation_set"
+        )
 
+        logger.debug("augmentation_set")
+
+        for k, v in augmentation_set_params.items():
+            setattr(augmentation_set, k, v)
+
+        for augmentation in augmentations:
+            logger.debug("augmentations:" + augmentation["name"])
+
+            call = self._kb.functions.create_function_call(augmentation["name"])
+
+            for k, v in augmentation["params"].items():
+                setattr(call, k, v)
+
+            augmentation_set.add_augmentation_call(call)
+
+        self._add_group_columns(augmentation_set)
+
+        self._add_passthrough_columns(augmentation_set)
+
+        self._add_label_column(augmentation_set)
+
+        self._augmentation_index = self.get_pipeline_length()
+
+        self._sandbox.add_linear_step(augmentation_set)
+
+    def _add_feature_selector(self, feature_selectors, selector_set_params={}):
+
+        self._check_for_input_data()
+        selector_set = self._kb.functions.create_selector_call_set("selector_set")
         logger.debug("feature_selector_set")
 
         for k, v in selector_set_params.items():
