@@ -201,14 +201,17 @@ class AutoSenseWidget(BaseWidget):
             ]
 
         if seed_choice == "Custom Feature Generatorset":
-            params[
-                "generatorset"
-            ] = self.custom_feature_generator.get_fature_generator()
+            subtype_list = self.custom_feature_generator.get_subtype_list()
+            self._dsk.pipeline.add_feature_generator(
+                [{"subtype_call": str(x)} for x in subtype_list],
+                function_defaults={"columns": self._dsk.pipeline.data_columns},
+            )
 
         print("Auto Sense Params", params)
         self._dsk.pipeline.describe()
 
         self._clear_auto_sense_results()
+
         self.results, self.summary = self._dsk.pipeline.auto(
             {"seed": seed_choice, "params": params}, renderer=self.renderer
         )
